<?php

/*
 * EVideoJS widget class file.
 *
 * EVideoJS extends CWidget and implements a base class for the VideoJS player.
 * More about VideoJS HTML5 Video Player can be found at http://videojs.com
 *
 * @version 1.0 - 20110209
 *
 * @author Marco Del Tongo <info@marcodeltongo.com>
 * @link http://www.marcodeltongo.com
 * @copyright Copyright &copy; 2011 Marco Del Tongo
 * @license New BSD License http://www.opensource.org/licenses/bsd-license.php
 */

class EVideoJS extends CWidget
{

	/**
	 * Mantains widget defaults.
	 *
	 * @var array
	 */
	public $_options = array(
		// Unique identifier, is autogenerated by default, useful for jQuery integrations.
		'id' => false,
		// Video and poster width in pixels
		'width' => 320,
		// Video and poster height in pixels
		'height' => 240,
		// Poster image absolute URL
		'poster' => false,
		// Absolute URL of the video in MP4 format
		'video_mp4' => false,
		// Absolute URL of the video in OGV format
		'video_ogv' => false,
		// Absolute URL of the video in WebM format
		'video_webm' => false,
		// Use Flash fallback player ?
		'flash_fallback' => true,
		// Address of custom Flash player to use as fallback
		'flash_player' => 'http://releases.flowplayer.org/swf/flowplayer-3.2.1.swf',
		// Show controls ?
		'controls' => true,
		// Preload video content ?
		'preload' => true,
		// Autostart the playback ?
		'autoplay' => false,
		// Show VideoJS support link ?
		'support' => true,
		// Show video download links ?
		'download' => true,
	);
	/**
	 * Mantains widget user options.
	 *
	 * @var array
	 */
	public $options = array();

	/**
	 * Simply publish our assets.
	 */
	public function init()
	{
		$this->publishAssets();
	}

	/**
	 * Simply map our options to player.
	 */
	public function run()
	{
		/*
		 * Get options
		 */
		extract($this->_options);
		extract($this->options);
		if (!$id) {
			$id = 'VideoJS_' . uniqid();
		}

		/*
		 * Start Video4All HTML
		 */
		echo "<!-- Begin VideoJS -->\n<div id='$id' ";
		echo "class='video-js-box'>\n<!-- Using the Video for Everybody Embed Code http://camendesign.com/code/video_for_everybody -->";

		/*
		 * Video tag
		 */
		echo '<video class="video-js" width="', $width, '" height="', $height, '"';
		if ($controls) {
			echo ' controls';
		}
		if ($preload) {
			echo ' preload';
		}
		if ($autoplay) {
			echo ' autoplay';
		}
		if ($poster) {
			echo ' poster="', $poster, '"';
		}
		echo ">\n";

		/*
		 * Video types
		 */
		if ($video_mp4) {
			echo '<source src="', $video_mp4, '" type=\'video/mp4; codecs="avc1.42E01E, mp4a.40.2"\' />', "\n";
		}
		if ($video_webm) {
			echo '<source src="', $video_webm, '" type=\'video/webm; codecs="vp8, vorbis"\' />', "\n";
		}
		if ($video_ogv) {
			echo '<source src="', $video_ogv, '" type=\'video/ogg; codecs="theora, vorbis"\' />', "\n";
		}

		/*
		 * Flash fallback
		 */
		if ($flash_fallback) {
			echo "<!-- Flash Fallback. Use any flash video player here. Make sure to keep the vjs-flash-fallback class. -->\n";
			echo '<object id="flash_fallback_', uniqid(), 'class="vjs-flash-fallback" width="', $width, '" height="', $height, '" type="application/x-shockwave-flash"';
			if ($flash_player) {
				echo 'data="', $flash_player, '"';
			}
			echo ">\n";

			echo "<param name='movie' value='$flash_player' />\n<param name='allowfullscreen' value='true' />\n";
			echo '<param name="flashvars" value=\'config={"playlist":["', $poster, '", {"url": "', $video_mp4, '","autoPlay":', (($autoplay) ? 'true' : 'false'), ',"autoBuffering":true}]}\' />', "\n";

			echo "<!-- Image Fallback. Typically the same as the poster image. -->\n";
			echo "<img src='$poster' width='$width' height='$height' alt='Poster Image' title='No video playback capabilities.' />";
			echo "\n</object>\n";
		}

		/*
		 * Close video tag
		 */
		echo "</video>\n";

		/*
		 * Downloads
		 */
		if ($download) {
			echo "<!-- Download links provided for devices that can't play video in the browser. -->\n<p class='vjs-no-video'><strong>Download Video:</strong>\n";

			if ($video_mp4) {
				echo '<a href="', $video_mp4, '">MP4</a>', "\n";
			}
			if ($video_webm) {
				echo '<a href="', $video_webm, '">WebM</a>', "\n";
			}
			if ($video_ogv) {
				echo '<a href="', $video_ogv, '">Ogg</a>', "\n";
			}

			if ($support) {
				echo '<br /><!-- Support VideoJS by keeping this link. --><a href="http://videojs.com">HTML5 Video Player</a> by VideoJS';
			}

			echo "\n</p>\n";
		}

		echo "</div>\n<!-- End VideoJS -->";
	}

	protected static function publishAssets()
	{
		$assets = dirname(__FILE__) . '/assets';
		$baseUrl = Yii::app()->assetManager->publish($assets);
		if (is_dir($assets)) {
			Yii::app()->clientScript->registerCoreScript('jquery');
			Yii::app()->clientScript->registerScriptFile($baseUrl . '/video.js', CClientScript::POS_HEAD);
			Yii::app()->clientScript->registerCssFile($baseUrl . '/video-js.css');
		} else {
			throw new Exception('EVideoJS - Error: Couldn\'t find assets to publish.');
		}
	}

}